==> open-xchange-documents-backend_7.8.4.orig.tar.bz2: open-xchange-documents-backend-7.8.4/com.openexchange.office.filter.odf/src/com/openexchange/office/filter/ods/dom/ConditionalFormatHandler.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.filter.ods.dom;

import org.xml.sax.Attributes;
import com.openexchange.office.filter.odf.SaxContextHandler;

public class ConditionalFormatHandler extends SaxContextHandler {

	final private ConditionalFormats conditionalFormats;
	final private Ranges ranges;

	public ConditionalFormatHandler(SaxContextHandler parentContextHandler, ConditionalFormats conditionalFormats, Attributes attributes) {
		super(parentContextHandler);

		this.conditionalFormats = conditionalFormats;
		this.ranges = new Ranges((SpreadsheetContent)this.getFileDom(), attributes.getValue("calcext:target-range-address"));
	}

	@Override
	public SaxContextHandler startElement(Attributes attributes, String uri, String localName, String qName) {
		final String tmpID = "gen" + (conditionalFormats.getConditionalFormatList().size() + 1) + "-" + localName;

		if(qName.equals("calcext:condition") || qName.equals("calcext:date-is")) {
			final Condition condition = new Condition(attributes, ranges.clone(), tmpID);
			conditionalFormats.getConditionalFormatList().put(condition.getId(), condition);

		} else if(qName.equals("calcext:icon-set") || qName.equals("calcext:color-scale") || qName.equals("calcext:data-bar")) {
			final EntryHolderCondition condition = new EntryHolderCondition(attributes, ranges.clone(), localName, tmpID);
			conditionalFormats.getConditionalFormatList().put(condition.getId(), condition);

			return new ConditionalEntryHandler(this, condition);
		}
		return this;
	}
}

==> open-xchange-documents-backend_7.10.1.orig.tar.bz2: open-xchange-documents-backend-7.10.1/com.openexchange.office.filter.odf/src/com/openexchange/office/filter/ods/dom/ConditionalFormatHandler.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.office.filter.ods.dom;

import org.xml.sax.Attributes;
import com.openexchange.office.filter.odf.SaxContextHandler;

public class ConditionalFormatHandler extends SaxContextHandler {

	final private ConditionalFormats conditionalFormats;
	final private Ranges ranges;
	private int priority = 0;

	public ConditionalFormatHandler(SaxContextHandler parentContextHandler, ConditionalFormats conditionalFormats, Attributes attributes) {
		super(parentContextHandler);

		this.conditionalFormats = conditionalFormats;
		this.ranges = new Ranges((SpreadsheetContent)this.getFileDom(), attributes.getValue("calcext:target-range-address"));
	}

	@Override
	public SaxContextHandler startElement(Attributes attributes, String uri, String localName, String qName) {
		final String tmpID = "gen" + (conditionalFormats.getConditionalFormatList().size() + 1) + "-" + localName;

		if(qName.equals("calcext:condition") || qName.equals("calcext:date-is")) {
			final Condition condition = new Condition(attributes, priority++, ranges.clone(), tmpID);
			conditionalFormats.getConditionalFormatList().put(condition.getId(), condition);

		} else if(qName.equals("calcext:icon-set") || qName.equals("calcext:color-scale") || qName.equals("calcext:data-bar")) {
			final EntryHolderCondition condition = new EntryHolderCondition(attributes, priority++, ranges.clone(), localName, tmpID);
			conditionalFormats.getConditionalFormatList().put(condition.getId(), condition);

			return new ConditionalEntryHandler(this, condition);
		}
		return this;
	}
}
